# -*- coding: utf-8 -*-

from cpskin.core.interfaces import IFolderViewSelectedContent
from plone import api
from plone.testing import z2
from plone.app.testing import FunctionalTesting
from plone.app.testing import PloneWithPackageLayer
from plone.app.testing import applyProfile
from plone.app.testing import (login,
                               TEST_USER_NAME,
                               setRoles,
                               TEST_USER_ID)
from plone.app.robotframework.testing import AUTOLOGIN_LIBRARY_FIXTURE
from zope.interface import alsoProvides

import cpskin.slider


class CPSkinSliderPloneWithPackageLayer(PloneWithPackageLayer):
    """
    """
    def setUpZope(self, app, configurationContext):
        super(CPSkinSliderPloneWithPackageLayer, self).setUpZope(
            app,
            configurationContext
        )
        z2.installProduct(app, 'Products.DateRecurringIndex')

    def tearDownZope(self, app):
        # Uninstall products installed above
        z2.uninstallProduct(app, 'Products.DateRecurringIndex')

    def setUpPloneSite(self, portal):
        portal.portal_workflow.setDefaultChain('simple_publication_workflow')
        applyProfile(portal, 'cpskin.slider:testing')
        setRoles(portal, TEST_USER_ID, ['Manager'])
        login(portal, TEST_USER_NAME)
        slider_folder = api.content.create(
            type='Folder',
            title='Slider Folder',
            id='slider-folder',
            description='Mon slider folder',
            container=portal)
        slider_folder.setLayout('folderview')
        api.content.transition(obj=slider_folder, transition='publish')
        news1 = api.content.create(
            type='News Item',
            title='Foire aux boudins',
            id='1-foire-aux-boudins',
            description='Superbe foire',
            container=slider_folder)
        api.content.transition(obj=news1, transition='publish')
        news2 = api.content.create(
            type='News Item',
            title='Festival de danse folklorique',
            id='2-festival-de-danse-folklorique',
            description='Parfois synonyme de danse folklorique ou de danse traditionnelle...',  # noqa
            container=slider_folder)
        api.content.transition(obj=news2, transition='publish')
        event = api.content.create(
            type='Event',
            title='Evénement important',
            id='3-evenement-important',
            description='Un événement important va se produire...',
            container=slider_folder)
        api.content.transition(obj=event, transition='publish')
        collection = api.content.create(
            type='Collection',
            title='SliderCollection',
            container=slider_folder)
        api.content.transition(obj=collection, transition='publish')
        collection.display_type = 'slider-with-carousel'
        alsoProvides(collection, IFolderViewSelectedContent)
        catalog = api.portal.get_tool('portal_catalog')
        catalog.reindexObject(collection)
        query = [{'i': 'Type',
                  'o': 'plone.app.querystring.operation.string.is',
                  'v': ['News Item', 'Event'],
                  }]
        collection.setQuery(query)
        collection.setSort_on('getId')
        api.portal.set_registry_record('cpskin.core.interfaces.ICPSkinSettings.auto_play_slider', False)  # noqa


CPSKIN_SLIDER_FIXTURE = CPSkinSliderPloneWithPackageLayer(
    name='CPSKIN_SLIDER_FIXTURE',
    zcml_filename='testing.zcml',
    zcml_package=cpskin.slider)


CPSKIN_SLIDER_ROBOT_TESTING = FunctionalTesting(
    bases=(CPSKIN_SLIDER_FIXTURE, AUTOLOGIN_LIBRARY_FIXTURE,
           z2.ZSERVER_FIXTURE),
    name='cpskin.slider:Robot')



# -*- coding: utf-8 -*-
from plone.testing import layered
from cpskin.slider.testing import CPSKIN_SLIDER_ROBOT_TESTING

import robotsuite
import unittest


def test_suite():
    suite = unittest.TestSuite()
    suite.addTests([
        layered(robotsuite.RobotTestSuite('robot'),
                layer=CPSKIN_SLIDER_ROBOT_TESTING),
    ])
    return suite



from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.portlets.portlets import base
from plone.app.form.widgets.uberselectionwidget import UberSelectionWidget
from plone.portlet.collection.collection import (Assignment as BaseCollectionPortletAssignment,
                                                ICollectionPortlet,
                                                Renderer as BaseCollectionPortletRenderer)
from zope.formlib import form
from zope.interface import implements
from cpskin.slider import messageFactory as _


class ISliderCollectionPortlet(ICollectionPortlet):
    """
        Collection portlet
    """


class Assignment(BaseCollectionPortletAssignment):
    implements(ISliderCollectionPortlet)


class Renderer(BaseCollectionPortletRenderer):

    render = ViewPageTemplateFile('slidercollectionportlet.pt')


class AddForm(base.AddForm):
    """
       add form
    """
    form_fields = form.Fields(ISliderCollectionPortlet)

    def create(self, data):
        return Assignment(**data)

    label = _(u"Collection portlet with slider view")
    description = _(u"add a collection portlet with slider view")

    form_fields = form.Fields(ISliderCollectionPortlet)
    form_fields['target_collection'].custom_widget = UberSelectionWidget


class EditForm(base.EditForm):
    """Portlet edit form."""
    form_fields = form.Fields(ISliderCollectionPortlet)

    label = _(u"Collection portlet with slider view")
    description = _(u"edit a collection portlet with slider view")

    form_fields = form.Fields(ISliderCollectionPortlet)
    form_fields['target_collection'].custom_widget = UberSelectionWidget



# -*- coding: utf-8 -*-

version = '1.2.10.dev0'

from setuptools import setup, find_packages

long_description = (
    open('README.rst').read()
    + '\n' +
    'Contributors\n'
    '============\n'
    + '\n' +
    open('CONTRIBUTORS.rst').read()
    + '\n' +
    open('CHANGES.rst').read()
    + '\n')

setup(name='cpskin.slider',
      version=version,
      description='Slider package for cpskin',
      long_description=long_description,
      classifiers=[
          "Environment :: Web Environment",
          "Programming Language :: Python",
          "Programming Language :: Python :: 2.7",
          "Framework :: Plone",
          "Framework :: Plone :: 4.2",
          "Framework :: Plone :: 4.3",
      ],
      keywords='',
      author='IMIO',
      author_email='support@imio.be',
      url='https://github.com/imio/',
      license='gpl',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'Plone',
          'plone.api',
          'cpskin.locales',
          'cpskin.core',
          # -*- Extra requirements: -*-
      ],
      extras_require={
          'test': [
              'plone.api',
              'plone.app.robotframework',
              'plone.app.testing',
          ]
      },
      entry_points={},)
